import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SpawnType } from "@skeldjs/constant";
import { BaseRpcMessage } from "@skeldjs/protocol";
import { BasicEvent, EventEmitter, ExtractEventTypes } from "@skeldjs/events";
import { Hostable } from "./Hostable";
import { ComponentDespawnEvent, ComponentSpawnEvent } from "./events";
import { PlayerData } from "./PlayerData";
export declare type NetworkableConstructor<T> = {
    new (room: Hostable<any>, spawnType: SpawnType, netId: number, ownerId: number, flags: number, data?: HazelReader | any): T;
} | {
    new (room: Hostable<any>, spawnType: SpawnType, netId: number, ownerId: number, flags: number, data?: HazelReader | any, object?: Networkable<any, any>): T;
};
export declare type NetworkableEvents<RoomType extends Hostable = Hostable> = ExtractEventTypes<[
    ComponentSpawnEvent<RoomType>,
    ComponentDespawnEvent<RoomType>
]>;
/**
 * Represents a basic networkable object in Among Us.
 *
 * See {@link NetworkableEvents} for events to listen to.
 */
export declare class Networkable<DataT = any, T extends NetworkableEvents = NetworkableEvents, RoomType extends Hostable = Hostable> extends EventEmitter<T> {
    /**
     * The room that this component belongs to.
     */
    room: RoomType;
    /**
     * The type of object that this component belongs to.
     */
    spawnType: SpawnType;
    /**
     * The net ID of this component.
     */
    netId: number;
    /**
     * The ID of the owner of this component.
     */
    ownerId: number;
    /**
     * Flags for this object, see {@link SpawnFlag}.
     */
    flags: number;
    /**
     * The dirty state of this component.
     */
    dirtyBit: number;
    /**
     * The player that this component belongs to.
     */
    player?: PlayerData<RoomType>;
    components: Networkable<any, NetworkableEvents, RoomType>[];
    constructor(room: RoomType, spawnType: SpawnType, netId: number, ownerId: number, flags: number, data?: HazelReader | DataT);
    protected patch(data: DataT): void;
    emit<Event extends BasicEvent>(event: Event): Promise<Event>;
    get owner(): Hostable | PlayerData<RoomType> | undefined;
    Deserialize(reader: HazelReader, spawn?: boolean): void;
    Serialize(writer: HazelWriter, spawn?: boolean): boolean;
    PreSerialize(): void;
    HandleRpc(rpc: BaseRpcMessage): Promise<void>;
    FixedUpdate(delta: number): void;
    Awake(): void;
    Destroy(): void;
    /**
     * Get a certain component from the object.
     * @param component The component class to get.
     */
    getComponent<T extends Networkable>(component: NetworkableConstructor<T>): T | undefined;
    /**
     * Spawn this component if does not exist in the room it belongs in.
     */
    spawn(): void;
    /**
     * Despawns the component from the room it belongs in.
     */
    despawn(): void;
}
//# sourceMappingURL=Networkable.d.ts.map