"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Networkable = void 0;
const util_1 = require("@skeldjs/util");
const events_1 = require("@skeldjs/events");
/**
 * Represents a basic networkable object in Among Us.
 *
 * See {@link NetworkableEvents} for events to listen to.
 */
class Networkable extends events_1.EventEmitter {
    constructor(room, spawnType, netId, ownerId, flags, data) {
        super();
        /**
         * The dirty state of this component.
         */
        this.dirtyBit = 0;
        this.room = room;
        this.spawnType = spawnType;
        this.netId = netId;
        this.ownerId = ownerId;
        this.flags = flags;
        if (this.ownerId > -2) {
            this.player = this.owner;
        }
        else {
            this.player = undefined;
        }
        this.components = [];
        if (data) {
            if (data instanceof util_1.HazelReader) {
                this.Deserialize(data, true);
            }
            else {
                this.patch(data);
            }
        }
    }
    patch(data) {
        Object.assign(this, data);
    }
    async emit(event) {
        if (this.player) {
            await this.player.emit(event);
        }
        else if (this.owner) {
            await this.owner.emit(event);
        }
        return super.emitSync(event);
    }
    get owner() {
        if (this.ownerId !== -2) {
            return this.room.players.get(this.ownerId);
        }
        return this.room;
    }
    // eslint-disable-next-line @typescript-eslint/no-unused-vars, @typescript-eslint/no-empty-function
    Deserialize(reader, spawn = false) { }
    // eslint-disable-next-line @typescript-eslint/no-unused-vars, @typescript-eslint/no-empty-function
    Serialize(writer, spawn = false) {
        return false;
    }
    // eslint-disable-next-line @typescript-eslint/no-unused-vars, @typescript-eslint/no-empty-function
    PreSerialize() { }
    // eslint-disable-next-line @typescript-eslint/no-unused-vars, @typescript-eslint/no-empty-function
    async HandleRpc(rpc) { }
    // eslint-disable-next-line @typescript-eslint/no-unused-vars, @typescript-eslint/no-empty-function
    FixedUpdate(delta) { }
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    Awake() { }
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    Destroy() { }
    /**
     * Get a certain component from the object.
     * @param component The component class to get.
     */
    getComponent(component) {
        for (const comp of this.components) {
            if (comp instanceof component) {
                return comp;
            }
        }
        return undefined;
    }
    /**
     * Spawn this component if does not exist in the room it belongs in.
     */
    spawn() {
        return this.room.spawnComponent(this);
    }
    /**
     * Despawns the component from the room it belongs in.
     */
    despawn() {
        return this.room.despawnComponent(this);
    }
}
exports.Networkable = Networkable;
//# sourceMappingURL=Networkable.js.map