import { BasicEvent } from "@skeldjs/events";
import { AlterGameMessage } from "@skeldjs/protocol";
import { Hostable, PrivacyType } from "../../Hostable";
import { ProtocolEvent } from "../ProtocolEvent";
import { RoomEvent } from "../RoomEvent";
/**
 * Emitted when the privacy of the room is updated.
 */
export declare class RoomSetPrivacyEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly message: AlterGameMessage | undefined;
    /**
     * The old privacy of the room.
     */
    readonly oldPrivacy: PrivacyType;
    /**
     * The new privacy of the room.
     */
    readonly newPrivacy: PrivacyType;
    static eventName: "room.setprivacy";
    eventName: "room.setprivacy";
    private _alteredPrivacy;
    constructor(room: RoomType, message: AlterGameMessage | undefined, 
    /**
     * The old privacy of the room.
     */
    oldPrivacy: PrivacyType, 
    /**
     * The new privacy of the room.
     */
    newPrivacy: PrivacyType);
    /**
     * The altered privacy to set the room to, if changed.
     */
    get alteredPrivacy(): PrivacyType;
    /**
     * Revert the room's privacy to its old privacy.
     */
    revert(): void;
    /**
     * Change the privacy that the room was set to.
     * @param privacy The privacy to set.
     */
    setPrivacy(privacy: PrivacyType): void;
}
//# sourceMappingURL=SetPrivacy.d.ts.map