"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MiraShipStatus = void 0;
const util_1 = require("@skeldjs/util");
const constant_1 = require("@skeldjs/constant");
const data_1 = require("@skeldjs/data");
const systems_1 = require("../systems");
const InnerShipStatus_1 = require("./InnerShipStatus");
/**
 * Represents a room object for the Mira HQ map.
 *
 * See {@link ShipStatusEvents} for events to listen to.
 */
class MiraShipStatus extends InnerShipStatus_1.InnerShipStatus {
    constructor(room, spawnType, netId, ownerid, flags, data) {
        super(room, spawnType, netId, ownerid, flags, data);
        this.initialSpawnCenter = new util_1.Vector2(16.64, 2.2);
        this.meetingSpawnCenter = new util_1.Vector2(24.043, 1.72);
    }
    getComponent(component) {
        if (this.spawnType === constant_1.SpawnType.MiraShipStatus && component === MiraShipStatus) {
            return this.components[0];
        }
        return super.getComponent(component);
    }
    get owner() {
        return super.owner;
    }
    Setup() {
        this.systems.set(constant_1.SystemType.Reactor, new systems_1.ReactorSystem(this, constant_1.SystemType.Reactor, {
            timer: 10000,
            completed: new Set,
        }));
        this.systems.set(constant_1.SystemType.Electrical, new systems_1.SwitchSystem(this, constant_1.SystemType.Electrical, {
            expected: [false, false, false, false, false],
            actual: [false, false, false, false, false],
            brightness: 255,
        }));
        this.systems.set(constant_1.SystemType.O2, new systems_1.LifeSuppSystem(this, constant_1.SystemType.O2, {
            timer: 10000,
            completed: new Set,
        }));
        this.systems.set(constant_1.SystemType.MedBay, new systems_1.MedScanSystem(this, constant_1.SystemType.MedBay, {
            queue: [],
        }));
        this.systems.set(constant_1.SystemType.Communications, new systems_1.HqHudSystem(this, constant_1.SystemType.Communications, {
            activeConsoles: [],
            completedConsoles: new Set([0, 1]),
        }));
        this.systems.set(constant_1.SystemType.Sabotage, new systems_1.SabotageSystem(this, constant_1.SystemType.Sabotage, {
            cooldown: 0,
        }));
        this.systems.set(constant_1.SystemType.Decontamination, new systems_1.DeconSystem(this, constant_1.SystemType.Decontamination, {
            timer: 10000,
            state: 0,
        }));
    }
    getDoorsInRoom(room) {
        return [];
    }
    getTasks() {
        return Object.values(data_1.MiraHQTasks);
    }
}
exports.MiraShipStatus = MiraShipStatus;
//# sourceMappingURL=MiraShipStatus.js.map